@@ -1765,11 +1765,18 @@ def local_channel_credentials(local_connect_type=LocalConnectionType.LOCAL_TCP):
     This is an EXPERIMENTAL API.
 
     Local credentials are used by local TCP endpoints (e.g. localhost:10000)
-    also UDS connections. It allows them to create secure channel, hence
-    transmitting call credentials become possible.
+    also UDS connections.
 
-    It is useful for 1) eliminating insecure_channel usage; 2) enable unit
-    testing for call credentials without setting up secrets.
+    The connections created by local channel credentials are not
+    encrypted, but will be checked if they are local or not.
+    The UDS connections are considered secure by providing peer authentication
+    and data confidentiality while TCP connections are considered insecure.
+
+    It is allowed to transmit call credentials over connections created by
+    local channel credentials.
+
+    Local channel credentials are useful for 1) eliminating insecure_channel usage;
+    2) enable unit testing for call credentials without setting up secrets.
 
     Args:
       local_connect_type: Local connection type (either
@@ -1788,11 +1795,18 @@ def local_server_credentials(local_connect_type=LocalConnectionType.LOCAL_TCP):
     This is an EXPERIMENTAL API.
 
     Local credentials are used by local TCP endpoints (e.g. localhost:10000)
-    also UDS connections. It allows them to create secure channel, hence
-    transmitting call credentials become possible.
+    also UDS connections.
 
-    It is useful for 1) eliminating insecure_channel usage; 2) enable unit
-    testing for call credentials without setting up secrets.
+    The connections created by local server credentials are not
+    encrypted, but will be checked if they are local or not.
+    The UDS connections are considered secure by providing peer authentication
+    and data confidentiality while TCP connections are considered insecure.
+
+    It is allowed to transmit call credentials over connections created by local
+    server credentials.
+
+    Local server credentials are useful for 1) eliminating insecure_channel usage;
+    2) enable unit testing for call credentials without setting up secrets.
 
     Args:
       local_connect_type: Local connection type (either
